"""标签数据类型枚举."""
from enum import Enum


class TagTypeEnum(Enum):
    """标签值的数据类型枚举.

    --------------------------------------------------
    |类型    | 描述	        |  字节数 |   数值范围      |
    +-------+---------------+--------+----------------
    |SINT   |有符号单字节类型	| 1	     | -2^7 ~ 2^7    |
    +-------+---------------+--------+----------------
    |INT    |有符号双字节类型	| 2	     | -2^15 ~ 2^15  |
    +-------+---------------+--------+----------------
    |DINT   |有符号四字节类型	| 4	     | -2^31 ~ 2^31  |
    +-------+---------------+--------+----------------
    |LINT   |有符号八字节类型	| 8	     | -2^63 ~ 2^63  |
    +-------+---------------+--------+----------------
    |BYTE   |无符号单字节类型	| 1	     | 0~ 2^8        |
    +-------+---------------+--------+----------------
    |WORD   |无符号双字节类型	| 2	     | 0 ~ 2^16      |
    +-------+---------------+--------+----------------
    |DWORD  |无符号四字节类型	| 4	     | 0 ~ 2^32      |
    +-------+---------------+--------+----------------
    |LWORD  |无符号八字节类型	| 8	     | 0 ~ 2^64      |
    +-------+---------------+--------+----------------
    |REAL   |四字节浮点类型    |4       |               |
    +-------+---------------+--------+----------------
    |LREAL  |八字节浮点类型    |8       |               |
    --------------------------------------------------
    """
    BOOL = "BOOL"  # bool类型
    STRING = "STRING"  # 字符串类型

    SINT = "SINT"  # 有符号单字节类型, 范围 -2^7 ~ 2^7, -128 ~ 127
    INT = "INT"  # 有符号双字节类型, 范围 -2^15 ~ 2^15, -32768 ~ 32767
    DINT = "DINT"  # 有符号四字节类型, 范围 -2^31 ~ 2^31, -2147483648  ~ 2147483647
    LINT = "LINT"  # 有符号八字节类型, 范围 -2^63 ~ 2^63, -9223372036854775808  ~ 9223372036854775807

    BYTE = "BYTE"  # 无符号单字节类型, 范围 0~ 2^8 - 1, 0 ~ 255
    WORD = "WORD"  # 无符号双字节类型, 范围 0 ~ 2^16 - 1, 0 ~ 65535
    DWORD = "DWORD"  # 无符号四字节类型, 范围 0 ~ 2^32 - 1, 0 ~ 4294967295
    LWORD = "LWORD"  # 无符号八字节类型, 范围 0 ~ 2^64 - 1, 0 ~ 18446744073709551615

    REAL = "REAL"  # 四字节浮点类型
    LREAL = "LREAL"  # 八字节浮点类型
